/*
 * ========================================================================
 *
 * Codehaus Cargo, copyright 2004-2011 Vincent Massol, 2012-2024 Ali Tokmen.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * ========================================================================
 */
package org.codehaus.cargo.container.websphere;

import org.codehaus.cargo.container.ContainerType;
import org.codehaus.cargo.container.configuration.ConfigurationType;
import org.codehaus.cargo.container.deployer.DeployerType;
import org.codehaus.cargo.container.internal.J2EEContainerCapability;
import org.codehaus.cargo.container.websphere.internal.WebSphere85xExistingLocalConfigurationCapability;
import org.codehaus.cargo.container.websphere.internal.WebSphere85xStandaloneLocalConfigurationCapability;
import org.codehaus.cargo.container.websphere.internal.WebSphere9xExistingLocalConfigurationCapability;
import org.codehaus.cargo.container.websphere.internal.WebSphere9xStandaloneLocalConfigurationCapability;
import org.codehaus.cargo.generic.AbstractFactoryRegistry;
import org.codehaus.cargo.generic.ContainerCapabilityFactory;
import org.codehaus.cargo.generic.ContainerFactory;
import org.codehaus.cargo.generic.configuration.ConfigurationCapabilityFactory;
import org.codehaus.cargo.generic.configuration.ConfigurationFactory;
import org.codehaus.cargo.generic.deployable.DeployableFactory;
import org.codehaus.cargo.generic.deployer.DeployerFactory;
import org.codehaus.cargo.generic.packager.PackagerFactory;

/**
 * Registers WebSphere support into default factories.
 */
public class WebSphereFactoryRegistry extends AbstractFactoryRegistry
{

    /**
     * Register deployable factory. Doesn't register anything.
     * 
     * @param deployableFactory Factory on which to register.
     */
    @Override
    protected void register(DeployableFactory deployableFactory)
    {
    }

    /**
     * Register configuration capabilities.
     * 
     * @param configurationCapabilityFactory Factory on which to register.
     */
    @Override
    protected void register(ConfigurationCapabilityFactory configurationCapabilityFactory)
    {
        configurationCapabilityFactory.registerConfigurationCapability("websphere85x",
            ContainerType.INSTALLED, ConfigurationType.STANDALONE,
            WebSphere85xStandaloneLocalConfigurationCapability.class);
        configurationCapabilityFactory.registerConfigurationCapability("websphere85x",
            ContainerType.INSTALLED, ConfigurationType.EXISTING,
            WebSphere85xExistingLocalConfigurationCapability.class);

        configurationCapabilityFactory.registerConfigurationCapability("websphere9x",
            ContainerType.INSTALLED, ConfigurationType.STANDALONE,
            WebSphere9xStandaloneLocalConfigurationCapability.class);
        configurationCapabilityFactory.registerConfigurationCapability("websphere9x",
            ContainerType.INSTALLED, ConfigurationType.EXISTING,
            WebSphere9xExistingLocalConfigurationCapability.class);
    }

    /**
     * Register configuration factories.
     * 
     * @param configurationFactory Factory on which to register.
     */
    @Override
    protected void register(ConfigurationFactory configurationFactory)
    {
        configurationFactory.registerConfiguration("websphere85x",
            ContainerType.INSTALLED, ConfigurationType.STANDALONE,
            WebSphere85xStandaloneLocalConfiguration.class);
        configurationFactory.registerConfiguration("websphere85x",
            ContainerType.INSTALLED, ConfigurationType.EXISTING,
            WebSphere85xExistingLocalConfiguration.class);

        configurationFactory.registerConfiguration("websphere9x",
            ContainerType.INSTALLED, ConfigurationType.STANDALONE,
            WebSphere9xStandaloneLocalConfiguration.class);
        configurationFactory.registerConfiguration("websphere9x",
            ContainerType.INSTALLED, ConfigurationType.EXISTING,
            WebSphere9xExistingLocalConfiguration.class);
    }

    /**
     * Register deployer.
     * 
     * @param deployerFactory Factory on which to register.
     */
    @Override
    protected void register(DeployerFactory deployerFactory)
    {
        deployerFactory.registerDeployer("websphere85x", DeployerType.INSTALLED,
            WebSphere85xInstalledLocalDeployer.class);
        deployerFactory.registerDeployer("websphere9x", DeployerType.INSTALLED,
            WebSphere9xInstalledLocalDeployer.class);
    }

    /**
     * Register packager. Doesn't register anything.
     * 
     * @param packagerFactory Factory on which to register.
     */
    @Override
    protected void register(PackagerFactory packagerFactory)
    {
    }

    /**
     * Register container.
     * 
     * @param containerFactory Factory on which to register.
     */
    @Override
    protected void register(ContainerFactory containerFactory)
    {
        containerFactory.registerContainer("websphere85x", ContainerType.INSTALLED,
            WebSphere85xInstalledLocalContainer.class);
        containerFactory.registerContainer("websphere9x", ContainerType.INSTALLED,
            WebSphere9xInstalledLocalContainer.class);
    }

    /**
     * Register container capabilities.
     * 
     * @param containerCapabilityFactory Factory on which to register.
     */
    @Override
    protected void register(ContainerCapabilityFactory containerCapabilityFactory)
    {
        containerCapabilityFactory.registerContainerCapability("websphere85x",
            J2EEContainerCapability.class);
        containerCapabilityFactory.registerContainerCapability("websphere9x",
            J2EEContainerCapability.class);
    }

}
